@@ -1,7 +1,8 @@
 import numbers
 import sys
 
-from collections import OrderedDict, Iterable, Hashable
+from collections import OrderedDict
+from collections.abc import Iterable, Hashable
 
 import numpy as np
 import pandas as pd
@@ -86,11 +87,15 @@ def _add_backgroundtile(
 
     elif not tile_provider is None:
         if not isinstance(tile_provider, str):
-            raise ValueError(f"<tile_provider> only accepts the values: {TILE_PROVIDERS}")
+            raise ValueError(
+                f"<tile_provider> only accepts the values: {TILE_PROVIDERS}"
+            )
         elif _get_background_tile(tile_provider) != False:
             t = p.add_tile(_get_background_tile(tile_provider))
         else:
-            raise ValueError(f"<tile_provider> only accepts the values: {TILE_PROVIDERS}")
+            raise ValueError(
+                f"<tile_provider> only accepts the values: {TILE_PROVIDERS}"
+            )
         t.alpha = tile_alpha
 
     return p
@@ -109,8 +114,9 @@ def _get_figure(col):
             return _get_figure(children)
 
 
-def convert_geoDataFrame_to_patches(gdf, geometry_column_name="geometry"):
-    """Creates from a geoDataFrame with Polygons and Multipolygons a Pandas DataFrame with x any y columns specifying the geometry of the Polygons"""
+def convert_geoDataFrame_to_patches(gdf, geometry_column):
+    """Creates from a geoDataFrame with Polygons and Multipolygons a Pandas DataFrame 
+    with x any y columns specifying the geometry of the Polygons."""
 
     df_new = []
 
@@ -130,7 +136,7 @@ def convert_geoDataFrame_to_patches(gdf, geometry_column_name="geometry"):
         return row
 
     for i, row in gdf.iterrows():
-        geometry = row[geometry_column_name]
+        geometry = row[geometry_column]
         if geometry.type == "Polygon":
             df_new.append(add_x_and_y_columns(row, geometry))
 
@@ -140,7 +146,7 @@ def convert_geoDataFrame_to_patches(gdf, geometry_column_name="geometry"):
 
     df_new = pd.DataFrame(df_new)
 
-    df_new = df_new.drop(columns=["geometry"])
+    df_new = df_new.drop(columns=[geometry_column])
     return df_new
 
 
@@ -158,6 +164,7 @@ def get_tick_formatter(formatter_arg):
 
 def geoplot(
     gdf_in,
+    geometry_column="geometry",
     figure=None,
     figsize=None,
     title="",
@@ -194,7 +201,7 @@ def geoplot(
     return_html=False,
     legend=True,
     webgl=True,
-    **kwargs
+    **kwargs,
 ):
     """Doc-String: TODO"""
 
@@ -210,7 +217,7 @@ def geoplot(
         ColorBar,
         BasicTicker,
         LogTicker,
-        Dropdown,
+        Select,
         Slider,
         ColumnDataSource,
     )
@@ -232,7 +239,9 @@ def geoplot(
         if "Polygon" in str(gdf.geom_type.unique()):
             layertypes.append("Polygon")
         if len(layertypes) > 1:
-            raise Exception(f"Can only plot GeoDataFrames/Series with single type of geometry (either Point, Line or Polygon). Provided is a GeoDataFrame/Series with types: {layertypes}")
+            raise Exception(
+                f"Can only plot GeoDataFrames/Series with single type of geometry (either Point, Line or Polygon). Provided is a GeoDataFrame/Series with types: {layertypes}"
+            )
     else:
         layertypes = ["Point"]
 
@@ -257,12 +266,12 @@ def geoplot(
 
     if type(gdf) != pd.DataFrame:
         # Convert GeoDataFrame to Web Mercator Projection:
-        gdf.to_crs({"init": "epsg:3857"}, inplace=True)
+        gdf.to_crs(epsg=3857, inplace=True)
 
         # Simplify shapes if wanted:
         if isinstance(simplify_shapes, numbers.Number):
             if layertypes[0] in ["Line", "Polygon"]:
-                gdf["geometry"] = gdf["geometry"].simplify(simplify_shapes)
+                gdf[geometry_column] = gdf[geometry_column].simplify(simplify_shapes)
         elif not simplify_shapes is None:
             raise ValueError(
                 "<simplify_shapes> parameter only accepts numbers or None."
@@ -294,7 +303,9 @@ def geoplot(
     elif category in gdf.columns:
         pass
     else:
-        raise ValueError(f"Could not find column '{category}' in GeoDataFrame. For <category>, please provide an existing single column of the GeoDataFrame.")
+        raise ValueError(
+            f"Could not find column '{category}' in GeoDataFrame. For <category>, please provide an existing single column of the GeoDataFrame."
+        )
 
     # Check for dropdown (multiple choropleth plots via dropdown selection):
     if dropdown is None:
@@ -306,7 +317,9 @@ def geoplot(
     else:
         for col in dropdown:
             if col not in gdf.columns:
-                raise ValueError(f"Could not find column '{col}' for <dropdown> in GeoDataFrame. ")
+                raise ValueError(
+                    f"Could not find column '{col}' for <dropdown> in GeoDataFrame. "
+                )
 
     # Check for slider (multiple choropleth plots via slider selection):
     if slider is None:
@@ -318,7 +331,9 @@ def geoplot(
     else:
         for col in slider:
             if col not in gdf.columns:
-                raise ValueError(f"Could not find column '{col}' for <slider> in GeoDataFrame. ")
+                raise ValueError(
+                    f"Could not find column '{col}' for <slider> in GeoDataFrame. "
+                )
 
         if not slider_range is None:
             if not isinstance(slider_range, Iterable):
@@ -352,15 +367,21 @@ def geoplot(
             if len(colormap) > 1:
                 pass
             else:
-                raise ValueError(f"<colormap> only accepts a list/tuple of at least two colors or the name of one of the following predefined colormaps (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}")
+                raise ValueError(
+                    f"<colormap> only accepts a list/tuple of at least two colors or the name of one of the following predefined colormaps (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}"
+                )
         elif isinstance(colormap, str):
             if colormap in all_palettes:
                 colormap = all_palettes[colormap]
                 colormap = colormap[max(colormap.keys())]
             else:
-                raise ValueError(f"Could not find <colormap> with name {colormap}. The following predefined colormaps are supported (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}")
+                raise ValueError(
+                    f"Could not find <colormap> with name {colormap}. The following predefined colormaps are supported (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}"
+                )
         else:
-            raise ValueError(f"<colormap> only accepts a list/tuple of at least two colors or the name of one of the following predefined colormaps (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}")
+            raise ValueError(
+                f"<colormap> only accepts a list/tuple of at least two colors or the name of one of the following predefined colormaps (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}"
+            )
     else:
         if isinstance(color, str):
             colormap = [color]
@@ -375,10 +396,6 @@ def geoplot(
     if xlim is not None:
         if isinstance(xlim, (tuple, list)):
             if len(xlim) == 2:
-                from pyproj import Proj, transform
-
-                inProj = Proj(init="epsg:4326")
-                outProj = Proj(init="epsg:3857")
                 xmin, xmax = xlim
                 for _ in [xmin, xmax]:
                     if not -180 < _ <= 180:
@@ -387,8 +404,11 @@ def geoplot(
                         )
                 if not xmin < xmax:
                     raise ValueError("xmin has to be smaller than xmax.")
-                xmin = transform(inProj, outProj, xmin, 0)[0]
-                xmax = transform(inProj, outProj, xmax, 0)[0]
+
+                from pyproj import Transformer
+                transformer = Transformer.from_crs("epsg:4326", "epsg:3857")
+                xmin = transformer.transform(0, xmin)[0]
+                xmax = transformer.transform(0, xmax)[0]
                 figure_options["x_range"] = (xmin, xmax)
             else:
                 raise ValueError(
@@ -401,10 +421,6 @@ def geoplot(
     if ylim is not None:
         if isinstance(ylim, (tuple, list)):
             if len(ylim) == 2:
-                from pyproj import Proj, transform
-
-                inProj = Proj(init="epsg:4326")
-                outProj = Proj(init="epsg:3857")
                 ymin, ymax = ylim
                 for _ in [ymin, ymax]:
                     if not -90 < _ <= 90:
@@ -413,8 +429,11 @@ def geoplot(
                         )
                 if not ymin < ymax:
                     raise ValueError("ymin has to be smaller than ymax.")
-                ymin = transform(inProj, outProj, 0, ymin)[1]
-                ymax = transform(inProj, outProj, 0, ymax)[1]
+
+                from pyproj import Transformer
+                transformer = Transformer.from_crs("epsg:4326", "epsg:3857")
+                ymin = transformer.transform(ymin,0)[1]
+                ymax = transformer.transform(ymax,0)[1]
                 figure_options["y_range"] = (ymin, ymax)
             else:
                 raise ValueError(
@@ -464,7 +483,9 @@ def geoplot(
     elif not category is None:
         # Check if category column is numerical:
         if not issubclass(gdf[category].dtype.type, np.number):
-            raise NotImplementedError(f"<category> plot only yet implemented for numerical columns. Column '{category}' is not numerical.")
+            raise NotImplementedError(
+                f"<category> plot only yet implemented for numerical columns. Column '{category}' is not numerical."
+            )
 
         field = category
         colormapper_options = {"palette": colormap}
@@ -491,7 +512,9 @@ def geoplot(
         # Check if all columns in dropdown selection are numerical:
         for col in dropdown:
             if not issubclass(gdf[col].dtype.type, np.number):
-                raise NotImplementedError(f"<dropdown> plot only yet implemented for numerical columns. Column '{col}' is not numerical.")
+                raise NotImplementedError(
+                    f"<dropdown> plot only yet implemented for numerical columns. Column '{col}' is not numerical."
+                )
 
         field = dropdown[0]
         colormapper_options = {"palette": colormap}
@@ -517,7 +540,9 @@ def geoplot(
         # Check if all columns in dropdown selection are numerical:
         for col in slider:
             if not issubclass(gdf[col].dtype.type, np.number):
-                raise NotImplementedError(f"<slider> plot only yet implemented for numerical columns. Column '{col}' is not numerical.")
+                raise NotImplementedError(
+                    f"<slider> plot only yet implemented for numerical columns. Column '{col}' is not numerical."
+                )
 
         field = slider[0]
         colormapper_options = {"palette": colormap}
@@ -559,7 +584,7 @@ def geoplot(
         if not isinstance(hovertool_columns, (list, tuple)):
             if hovertool_columns == "all":
                 hovertool_columns = list(
-                    filter(lambda col: col != "geometry", gdf.columns)
+                    filter(lambda col: col != geometry_column, gdf.columns)
                 )
             else:
                 raise ValueError(
@@ -577,7 +602,9 @@ def geoplot(
         else:
             for col in hovertool_columns:
                 if col not in gdf.columns:
-                    raise ValueError(f"Could not find columns '{col}' in GeoDataFrame. <hovertool_columns> has to be a list of columns of the GeoDataFrame or the string 'all'.")
+                    raise ValueError(
+                        f"Could not find columns '{col}' in GeoDataFrame. <hovertool_columns> has to be a list of columns of the GeoDataFrame or the string 'all'."
+                    )
     else:
         if category is None:
             hovertool_columns = []
@@ -589,7 +616,7 @@ def geoplot(
         gdf["Geometry"] = 0
         additional_columns = ["x", "y"]
     else:
-        additional_columns = ["geometry"]
+        additional_columns = [geometry_column]
     for kwarg, value in kwargs.items():
         if isinstance(value, Hashable):
             if value in gdf.columns:
@@ -616,14 +643,16 @@ def geoplot(
     if "Point" in layertypes:
         if "line_color" not in kwargs:
             kwargs["line_color"] = kwargs["fill_color"]
-        glyph = p.scatter(x="x", y="y", source=geo_source, legend=legend, **kwargs)
+        glyph = p.scatter(
+            x="x", y="y", source=geo_source, legend_label=legend, **kwargs
+        )
 
     if "Line" in layertypes:
         if "line_color" not in kwargs:
             kwargs["line_color"] = kwargs["fill_color"]
             del kwargs["fill_color"]
         glyph = p.multi_line(
-            xs="xs", ys="ys", source=geo_source, legend=legend, **kwargs
+            xs="xs", ys="ys", source=geo_source, legend_label=legend, **kwargs
         )
 
     if "Polygon" in layertypes:
@@ -633,11 +662,13 @@ def geoplot(
 
         # Creates from a geoDataFrame with Polygons and Multipolygons a Pandas DataFrame
         # with x any y columns specifying the geometry of the Polygons:
-        geo_source = ColumnDataSource(convert_geoDataFrame_to_patches(gdf))
+        geo_source = ColumnDataSource(
+            convert_geoDataFrame_to_patches(gdf, geometry_column)
+        )
 
         # Plot polygons:
         glyph = p.multi_polygons(
-            xs="__x__", ys="__y__", source=geo_source, legend=legend, **kwargs
+            xs="__x__", ys="__y__", source=geo_source, legend_label=legend, **kwargs
         )
 
     # Add hovertool:
@@ -670,8 +701,8 @@ def geoplot(
     # Add Dropdown Widget:
     if not dropdown is None:
         # Define Dropdown widget:
-        dropdown_widget = Dropdown(
-            label="Select Choropleth Layer", menu=list(zip(dropdown, dropdown))
+        dropdown_widget = Select(
+            title="Select Choropleth Layer", options=list(zip(dropdown, dropdown))
         )
 
         # Define Callback for Dropdown widget:
@@ -737,6 +768,7 @@ def geoplot(
 
                 //Change selection of field for Colormapper for choropleth plot:
                 var slider_value = slider_widget.value;
+                var i;
                 for(i=0; i<value2name.data["Names"].length; i++)
                     {
                     if (value2name.data["Values"][i] == slider_value)
