@@ -14,10 +14,18 @@ import pandas as pd
 from bokeh.core.properties import value as _value
 from bokeh.events import Tap
 from bokeh.layouts import column
-from bokeh.models import (CategoricalColorMapper, ColorBar, ColumnDataSource,
-                          DatetimeTickFormatter, FuncTickFormatter, HoverTool,
-                          LinearColorMapper, LogColorMapper, RangeTool,
-                          WheelZoomTool)
+from bokeh.models import (
+    CategoricalColorMapper,
+    ColorBar,
+    ColumnDataSource,
+    DatetimeTickFormatter,
+    FuncTickFormatter,
+    HoverTool,
+    LinearColorMapper,
+    LogColorMapper,
+    RangeTool,
+    WheelZoomTool,
+)
 from bokeh.models.callbacks import CustomJS
 from bokeh.models.glyphs import Text
 from bokeh.models.ranges import FactorRange, Range1d
@@ -27,7 +35,7 @@ from bokeh.plotting import figure
 from bokeh.transform import cumsum, dodge
 from pandas.core.base import PandasObject
 
-from .base import embedded_html, show
+from .base import embedded_html, show, set_fontsizes_of_figure
 from .geoplot import geoplot
 
 
@@ -43,6 +51,7 @@ def check_type(data):
     else:
         return "object"
 
+
 def get_colormap(colormap, N_cols):
 
     """Returns a colormap with <N_cols> colors. <colormap> can be either None,
@@ -67,7 +76,9 @@ def get_colormap(colormap, N_cols):
                 colormap = colormap * int(N_cols / len(colormap) + 1)
                 colormap = colormap[:N_cols]
         else:
-            raise ValueError(f"Could not find <colormap> with name {colormap}. The following predefined colormaps are supported (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}")
+            raise ValueError(
+                f"Could not find <colormap> with name {colormap}. The following predefined colormaps are supported (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}"
+            )
     elif isinstance(colormap, (list, tuple)):
         colormap = colormap * int(N_cols / len(colormap) + 1)
         colormap = colormap[:N_cols]
@@ -120,7 +131,10 @@ def plot(
     yticks=None,
     xlim=None,
     ylim=None,
-    fontsize=None,  # TODO:
+    fontsize_title=None,
+    fontsize_label=None,
+    fontsize_ticks=None,
+    fontsize_legend=None,
     color=None,
     colormap=None,
     category=None,
@@ -147,8 +161,8 @@ def plot(
     vertical_xlabel=False,
     x_axis_location="below",
     webgl=True,
-    reuse_plot=None, # This keyword is not used by Pandas-Bokeh, but pandas plotting API adds it for series object calls
-    **kwargs
+    reuse_plot=None,  # This keyword is not used by Pandas-Bokeh, but pandas plotting API adds it for series object calls
+    **kwargs,
 ):
     """Method for creating a interactive with 'Bokeh' as plotting backend. Available
     plot kinds are:
@@ -207,7 +221,7 @@ def plot(
             hovertool=hovertool,
             hovertool_string=hovertool_string,
             webgl=webgl,
-            **kwargs
+            **kwargs,
         )
 
     # Check plot kind input:
@@ -224,10 +238,7 @@ def plot(
         "map",
     ]
 
-    rangetool_allowed_kinds = [
-        "line",
-        "step"
-    ]
+    rangetool_allowed_kinds = ["line", "step"]
 
     if kind not in allowed_kinds:
         allowed_kinds = "', '".join(allowed_kinds)
@@ -235,7 +246,9 @@ def plot(
 
     if rangetool and kind not in rangetool_allowed_kinds:
         allowed_rangetool_kinds = "', '".join(rangetool_allowed_kinds)
-        raise ValueError(f"For using the rangetool, the allowed plot kinds are '{allowed_rangetool_kinds}'.")
+        raise ValueError(
+            f"For using the rangetool, the allowed plot kinds are '{allowed_rangetool_kinds}'."
+        )
 
     if rangetool:
         x_axis_location = "above"
@@ -249,7 +262,7 @@ def plot(
         "plot_height": 400,
         "output_backend": "webgl",
         "sizing_mode": sizing_mode,
-        "x_axis_location": x_axis_location
+        "x_axis_location": x_axis_location,
     }
     # Initializing rangetool plot variable:
     p_rangetool = None
@@ -399,7 +412,9 @@ def plot(
     data_cols = []
     for i, col in enumerate(cols):
         if col not in df.columns:
-            raise Exception(f"Could not find '{col}' in the columns of the provided DataFrame/Series. Please provide for the <y> parameter either a column name of the DataFrame/Series or an array of the same length.")
+            raise Exception(
+                f"Could not find '{col}' in the columns of the provided DataFrame/Series. Please provide for the <y> parameter either a column name of the DataFrame/Series or an array of the same length."
+            )
         if np.issubdtype(df[col].dtype, np.number):
             data_cols.append(col)
     if len(data_cols) == 0:
@@ -415,7 +430,9 @@ def plot(
             data_cols.remove(delete_in_y)
     N_cols = len(data_cols)
     if len(data_cols) == 0:
-        raise Exception(f"The only numeric column is the column {delete_in_y} that is already used on the x-axis.")
+        raise Exception(
+            f"The only numeric column is the column {delete_in_y} that is already used on the x-axis."
+        )
 
     # Autodetect y-label if no y-label is provided by user and only one y-column exists:
     if N_cols == 1:
@@ -488,7 +505,7 @@ def plot(
             hovertool_string,
             number_format,
             rangetool,
-            **kwargs
+            **kwargs,
         )
 
     if kind == "step":
@@ -505,7 +522,7 @@ def plot(
             hovertool_string,
             number_format,
             rangetool,
-            **kwargs
+            **kwargs,
         )
 
     if kind == "point":
@@ -519,7 +536,7 @@ def plot(
             xlabelname,
             figure_options["x_axis_type"],
             number_format,
-            **kwargs
+            **kwargs,
         )
 
     if kind == "scatter":
@@ -542,8 +559,6 @@ def plot(
             if add_param in kwargs:
                 del kwargs[add_param]
 
-        
-
         # Get values for categorical colormap:
         category_values = None
         if category in df.columns:
@@ -568,7 +583,7 @@ def plot(
             x_axis_type=figure_options["x_axis_type"],
             xlabelname=xlabelname,
             ylabelname=y_column,
-            **kwargs
+            **kwargs,
         )
 
     if kind == "bar" or kind == "barh":
@@ -631,8 +646,8 @@ def plot(
                         width=width,
                         source=source,
                         color=color,
-                        legend=" " + name,
-                        **kwargs
+                        legend_label=" " + name,
+                        **kwargs,
                     )
                     hovermode = "vline"
 
@@ -643,8 +658,8 @@ def plot(
                         height=width,
                         source=source,
                         color=color,
-                        legend=" " + name,
-                        **kwargs
+                        legend_label=" " + name,
+                        **kwargs,
                     )
                     hovermode = "hline"
 
@@ -669,8 +684,8 @@ def plot(
                     width=0.8,
                     source=source,
                     color=colormap,
-                    legend=legend_ref,
-                    **kwargs
+                    legend_label=data_cols,
+                    **kwargs,
                 )
                 hovermode = "vline"
 
@@ -681,8 +696,8 @@ def plot(
                     height=0.8,
                     source=source,
                     color=colormap,
-                    legend=legend_ref,
-                    **kwargs
+                    legend_label=data_cols,
+                    **kwargs,
                 )
                 hovermode = "hline"
 
@@ -710,7 +725,9 @@ def plot(
 
         # Check for stacked keyword:
         if stacked and histogram_type not in [None, "stacked"]:
-            warnings.warn(f"<histogram_type> was set to '{histogram_type}', but was overriden by <stacked>=True parameter.")
+            warnings.warn(
+                f"<histogram_type> was set to '{histogram_type}', but was overriden by <stacked>=True parameter."
+            )
             histogram_type = "stacked"
         elif stacked and histogram_type is None:
             histogram_type = "stacked"
@@ -759,13 +776,19 @@ def plot(
                 values_not_nan = values[not_nan]
                 weights_not_nan = weights[not_nan]
                 if sum(not_nan) < len(not_nan):
-                    warnings.warn(f"There are NaN values in column '{col}' or in the <weights> column. For the histogram, these rows have been neglected.", Warning)
+                    warnings.warn(
+                        f"There are NaN values in column '{col}' or in the <weights> column. For the histogram, these rows have been neglected.",
+                        Warning,
+                    )
             else:
                 not_nan = ~np.isnan(values)
                 values_not_nan = values[not_nan]
                 weights_not_nan = None
                 if sum(not_nan) < len(not_nan):
-                    warnings.warn(f"There are NaN values in column '{col}'. For the histogram, these rows have been neglected.", Warning)
+                    warnings.warn(
+                        f"There are NaN values in column '{col}'. For the histogram, these rows have been neglected.",
+                        Warning,
+                    )
 
             average = np.average(values_not_nan, weights=weights_not_nan)
             averages.append(average)
@@ -795,7 +818,7 @@ def plot(
             show_average,
             histogram_type,
             logy,
-            **kwargs
+            **kwargs,
         )
 
     if kind == "area":
@@ -811,7 +834,7 @@ def plot(
             figure_options["x_axis_type"],
             stacked,
             normed,
-            **kwargs
+            **kwargs,
         )
 
     if kind == "pie":
@@ -825,7 +848,7 @@ def plot(
             hovertool_string,
             figure_options,
             xlabelname,
-            **kwargs
+            **kwargs,
         )
 
     # Set xticks:
@@ -893,6 +916,16 @@ def plot(
                 "Legend can only be True/False or one of 'top_left', 'top_center', 'top_right', 'center_left', 'center', 'center_right', 'bottom_left', 'bottom_center', 'bottom_right'"
             )
 
+    # Set fontsizes:
+    set_fontsizes_of_figure(
+        figure=p,
+        fontsize_title=fontsize_title,
+        fontsize_label=fontsize_label,
+        fontsize_ticks=fontsize_ticks,
+        fontsize_legend=fontsize_legend,
+    )
+
+
     # Scientific formatting for axes:
     if disable_scientific_axes is None:
         pass
@@ -911,7 +944,7 @@ def plot(
     # If rangetool is used, add it to layout:
     if p_rangetool is not None:
         p = column(p, p_rangetool)
-        
+
     # Display plot if wanted
     if show_figure:
         show(p)
@@ -938,12 +971,12 @@ def _base_lineplot(
     hovertool_string,
     number_format,
     rangetool,
-    **kwargs
+    **kwargs,
 ):
     """Adds lineplot to figure p for each data_col."""
 
     p_rangetool = None
-     # Add line (and optional scatter glyphs) to figure:
+    # Add line (and optional scatter glyphs) to figure:
     linetype = getattr(p, linetype.lower())
     marker = kwargs.pop("marker", "circle")
 
@@ -954,17 +987,17 @@ def _base_lineplot(
         glyph = linetype(
             x="__x__values",
             y=name,
-            legend=" " + name,
+            legend_label=" " + name,
             source=source,
             color=color,
-            **kwargs
+            **kwargs,
         )
 
         if plot_data_points:
             p.scatter(
                 x="__x__values",
                 y=name,
-                legend=" " + name,
+                legend_label=" " + name,
                 source=source,
                 color=color,
                 marker=marker,
@@ -979,7 +1012,7 @@ def _base_lineplot(
                         (xlabelname, "@__x__values_original{%F}"),
                         (name, "@{%s}%s" % (name, number_format)),
                     ]
-                    my_hover.formatters = {"__x__values_original": "datetime"}
+                    my_hover.formatters = {"@__x__values_original": "datetime"}
                 else:
                     my_hover.tooltips = [
                         (xlabelname, "@__x__values_original"),
@@ -989,19 +1022,13 @@ def _base_lineplot(
                 my_hover.tooltips = hovertool_string
             p.add_tools(my_hover)
 
-        if rangetool:           
+        if rangetool:
 
-            p_rangetool.line(
-                "__x__values",
-                name,
-                source=source,
-                color=color
-            )
+            p_rangetool.line("__x__values", name, source=source, color=color)
 
     return p, p_rangetool
 
 
-
 def lineplot(
     p,
     source,
@@ -1015,7 +1042,7 @@ def lineplot(
     hovertool_string,
     number_format,
     rangetool,
-    **kwargs
+    **kwargs,
 ):
     return _base_lineplot(
         linetype="line",
@@ -1031,7 +1058,7 @@ def lineplot(
         hovertool_string=hovertool_string,
         number_format=number_format,
         rangetool=rangetool,
-        **kwargs
+        **kwargs,
     )
 
 
@@ -1048,7 +1075,7 @@ def stepplot(
     hovertool_string,
     number_format,
     rangetool,
-    **kwargs
+    **kwargs,
 ):
     return _base_lineplot(
         linetype="step",
@@ -1064,7 +1091,7 @@ def stepplot(
         hovertool_string=hovertool_string,
         number_format=number_format,
         rangetool=rangetool,
-        **kwargs
+        **kwargs,
     )
 
 
@@ -1078,7 +1105,7 @@ def pointplot(
     xlabelname,
     x_axis_type,
     number_format,
-    **kwargs
+    **kwargs,
 ):
     """Adds pointplot to figure p for each data_col."""
 
@@ -1112,11 +1139,11 @@ def pointplot(
         glyph = p.scatter(
             x="__x__values",
             y=name,
-            legend=" " + name,
+            legend_label=" " + name,
             source=source,
             color=color,
             marker=marker,
-            **kwargs
+            **kwargs,
         )
         if hovertool:
             my_hover = HoverTool(mode="vline", renderers=[glyph])
@@ -1126,7 +1153,7 @@ def pointplot(
                         (xlabelname, "@__x__values_original{%F}"),
                         (name, "@{%s}%s" % (name, number_format)),
                     ]
-                    my_hover.formatters = {"__x__values_original": "datetime"}
+                    my_hover.formatters = {"@__x__values_original": "datetime"}
                 else:
                     my_hover.tooltips = [
                         (xlabelname, "@__x__values_original"),
@@ -1154,7 +1181,7 @@ def scatterplot(
     x_axis_type,
     xlabelname,
     ylabelname,
-    **kwargs
+    **kwargs,
 ):
     """Adds a scatterplot to figure p for each data_col."""
 
@@ -1192,7 +1219,9 @@ def scatterplot(
                     max_key = max(colormap.keys())
                     colormap = colormap[max_key]
                 else:
-                    raise ValueError(f"Could not find <colormap> with name {colormap}. The following predefined colormaps are supported (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}")
+                    raise ValueError(
+                        f"Could not find <colormap> with name {colormap}. The following predefined colormaps are supported (see also https://bokeh.pydata.org/en/latest/docs/reference/palettes.html ): {list(all_palettes.keys())}"
+                    )
             elif isinstance(colormap, (list, tuple)):
                 pass
             else:
@@ -1227,7 +1256,7 @@ def scatterplot(
                             (xlabelname, "@__x__values_original{%F}"),
                             (ylabelname, "@y"),
                         ]
-                        my_hover.formatters = {"__x__values_original": "datetime"}
+                        my_hover.formatters = {"@__x__values_original": "datetime"}
                     else:
                         my_hover.tooltips = [
                             (xlabelname, "@__x__values_original"),
@@ -1272,10 +1301,10 @@ def scatterplot(
                 glyph = p.scatter(
                     x="__x__values",
                     y="y",
-                    legend=str(cat) + " ",
+                    legend_label=str(cat) + " ",
                     source=source,
                     color=color,
-                    **kwargs
+                    **kwargs,
                 )
 
                 # Add Hovertool
@@ -1287,7 +1316,7 @@ def scatterplot(
                                 (xlabelname, "@__x__values_original{%F}"),
                                 (ylabelname, "@y"),
                             ]
-                            my_hover.formatters = {"__x__values_original": "datetime"}
+                            my_hover.formatters = {"@__x__values_original": "datetime"}
                         else:
                             my_hover.tooltips = [
                                 (xlabelname, "@__x__values_original"),
@@ -1312,7 +1341,7 @@ def scatterplot(
     else:
         # Draw glyph:
         glyph = p.scatter(
-            x="__x__values", y="y", source=source, legend="Hide/Show", **kwargs
+            x="__x__values", y="y", source=source, legend_label="Hide/Show", **kwargs
         )
 
         # Add Hovertool:
@@ -1324,7 +1353,7 @@ def scatterplot(
                         (xlabelname, "@__x__values_original{%F}"),
                         (ylabelname, "@y"),
                     ]
-                    my_hover.formatters = {"__x__values_original": "datetime"}
+                    my_hover.formatters = {"@__x__values_original": "datetime"}
                 else:
                     my_hover.tooltips = [
                         (xlabelname, "@__x__values_original"),
@@ -1353,7 +1382,7 @@ def histogram(
     show_average,
     histogram_type,
     logy,
-    **kwargs
+    **kwargs,
 ):
     "Adds histogram to figure p for each data_col."
 
@@ -1431,14 +1460,16 @@ def histogram(
             top="top",
             source=source,
             color=color,
-            legend=name,
-            **kwargs
+            legend_label=name,
+            **kwargs,
         )
 
         if hovertool:
             my_hover = HoverTool(mode="vline", renderers=[g1])
             if hovertool_string is None:
-                my_hover.tooltips = (f"<h3> {name}: </h3> <h4>bin=@bins</h4> <h4>value=@top </h4>")
+                my_hover.tooltips = (
+                    f"<h3> {name}: </h3> <h4>bin=@bins</h4> <h4>value=@top </h4>"
+                )
             else:
                 warnings.warn(
                     "For histograms, <hovertool_string> is not a supported keyword argument."
@@ -1456,7 +1487,7 @@ def histogram(
                     angle=sign * np.pi / 2,
                     line_width=3,
                     color=color,
-                    legend="<%s> = %f" % (name, average),
+                    legend_label="<%s> = %f" % (name, average),
                 )
 
     p.xaxis.ticker = bins
@@ -1475,7 +1506,7 @@ def areaplot(
     x_axis_type,
     stacked,
     normed,
-    **kwargs
+    **kwargs,
 ):
     """Adds areaplot to figure p for each data_col."""
 
@@ -1527,10 +1558,10 @@ def areaplot(
         p.patch(
             x="__x__values",
             y=name,
-            legend=" " + name,
+            legend_label=" " + name,
             source=source,
             color=color,
-            **kwargs
+            **kwargs,
         )
 
         # Add hovertool:
@@ -1544,7 +1575,7 @@ def areaplot(
             glyph = p.line(
                 x="__x__values",
                 y=y,
-                legend=" " + name,
+                legend_label=" " + name,
                 source=line_source,
                 color=color,
                 alpha=0,
@@ -1557,7 +1588,7 @@ def areaplot(
                     my_hover.tooltips = [(xlabelname, "@__x__values_original{%F}")] + [
                         (name, "@{%s}" % name) for name in data_cols[::-1]
                     ]
-                    my_hover.formatters = {"__x__values_original": "datetime"}
+                    my_hover.formatters = {"@__x__values_original": "datetime"}
                 else:
                     my_hover.tooltips = [(xlabelname, "@__x__values_original")] + [
                         (name, "@{%s}" % name) for name in data_cols[::-1]
@@ -1577,7 +1608,7 @@ def pieplot(
     hovertool_string,
     figure_options,
     xlabelname,
-    **kwargs
+    **kwargs,
 ):
 
     """Creates a Pieplot from the provided data."""
@@ -1639,7 +1670,7 @@ def pieplot(
             end_angle=cumsum(col + "_angle"),
             fill_color="color",
             source=source,
-            **kwargs
+            **kwargs,
         )
 
         # Add annotation:
@@ -2390,6 +2421,7 @@ class FramePlotMethods(BasePlotMethods):
         """
         return self(kind="map", x=x, y=y, **kwds)
 
+
 def _initialize_rangetool(p, x_axis_type, source):
     """
     Initializes the range tool chart and slider.
@@ -2422,8 +2454,8 @@ def _initialize_rangetool(p, x_axis_type, source):
     )
 
     # Need to explicitly set the initial range of the plot for the range tool.
-    start_index = int(0.75 * len(source['__x__values']))
-    p.x_range = Range1d(source['__x__values'][start_index], source['__x__values'][-1])
+    start_index = int(0.75 * len(source["__x__values"]))
+    p.x_range = Range1d(source["__x__values"][start_index], source["__x__values"][-1])
 
     range_tool = RangeTool(x_range=p.x_range)
     range_tool.overlay.fill_color = "navy"
